about summary refs log tree commit diff
path: root/users/tazjin/homepage
diff options
context:
space:
mode:
authorVincent Ambo <mail@tazj.in>2020-06-26T19·28+0100
committertazjin <mail@tazj.in>2020-06-26T19·33+0000
commit351ed4f044753bc4b1f3dcdc83b96a32f7dcaeeb (patch)
tree3b7040a87c393a399cade516a14a7bff64475747 /users/tazjin/homepage
parenta2cbbedc65c9200fd3c2a6a698366ac431cc153d (diff)
fix(tazjin/homepage): Fix configuration settings after page moves r/1088
My personal pages have moved out of //web, and various changes were
necessary to keep everything working.

Change-Id: I2f81fdd8ba2ce2ce6fea7e329bbdcda6092cc8a6
Reviewed-on: https://cl.tvl.fyi/c/depot/+/604
Reviewed-by: tazjin <mail@tazj.in>
Diffstat (limited to 'users/tazjin/homepage')
-rw-r--r--users/tazjin/homepage/default.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/users/tazjin/homepage/default.nix b/users/tazjin/homepage/default.nix
index 22380fdea7..9ac3112b03 100644
--- a/users/tazjin/homepage/default.nix
+++ b/users/tazjin/homepage/default.nix
@@ -4,7 +4,7 @@
 # The website is made up of a simple header&footer and content
 # elements for things such as blog posts and projects.
 #
 # Content for the blog is in //web/blog instead of here.
 { depot, lib, ... }:
 
 with depot;
@@ -28,7 +28,7 @@ let
 
   escape = replaceStrings [ "<" ">" "&" "'" ] [ "&lt;" "&gt;" "&amp;" "&#39;" ];
 
-  postToEntry = defun [ web.blog.post entry ] (post: {
+  postToEntry = defun [ users.tazjin.blog.post entry ] (post: {
     class = "blog";
     title = post.title;
     url = "/blog/${post.key}";
@@ -64,7 +64,7 @@ let
     ++ [ (builtins.readFile ./footer.html) ]
   ));
 
-  homepage = index ((map postToEntry web.blog.posts) ++ (import ./entries.nix));
+  homepage = index ((map postToEntry users.tazjin.blog.posts) ++ (import ./entries.nix));
 in runCommandNoCC "website" {} ''
   mkdir $out
   cp ${homepage} $out/index.html
@@ -4,7 +4,7 @@
 # elements for things such as blog posts and projects.
 #
-# Content for the blog is in //web/blog instead of here.
+# Content for the blog is in //users/tazjin/blog instead of here.
 { depot, lib, ... }:
 